@@ -1,4 +1,4 @@
-version = '3.7.0'
+version = '4.0.1'
 
 class generic:
     file_s_not_found = "File '%s' not found"
@@ -30,10 +30,10 @@ class sessions:
     error_loading_sessions = 'Session loading error'
     error_session_s_not_modified = 'Error setting session variable \'%s\''
     connection_info = """<%!
-import urlparse
+from urllib.parse import urlparse
 %><%
 if not host:
-    urlparsed = urlparse.urlparse(url)
+    urlparsed = urlparse(url)
     if urlparsed and urlparsed.netloc:
         hostname = urlparsed.netloc
     else:
@@ -72,13 +72,6 @@ following command replacements to simulate a unrestricted shell.
     set_usage = 'Set session variable (run :show to print). Usage:\n:set <variable> \'<value>\''
     unset_usage = 'Unset session variable (run :show to print). Usage:\n:unset <variable>'
 
-class stegareferrer:
-    error_generating_id = 'Error generating id, payload too long?'
-    error_password_hash = 'Error generating trigger, please use another password'
-    error_language_start_letter_s = 'Error, at least one language must start with the letter \'%s\''
-    error_chunk_position_i_s = 'Error chunk position %i is not indexable, delete template \'%s\''
-
-
 class vectors:
     wrong_target_type = 'Wrong target operating system type'
     wrong_arguments_type = 'Wrong formatting argument type, a dictionary is required'
@@ -248,11 +241,6 @@ class generate:
     error_obfuscator_template_s_s = 'Error with obfuscator template \'%s\': %s'
     generated_backdoor_with_password_s_in_s_size_i = 'Generated \'%s\' with password \'%s\' of %i byte size.'
 
-class utils_code:
-    minify_php_missing_binary = 'Missing PHP binary, skipping PHP code minify'
-    minify_php_error_minifying = 'Error minifying PHP code, skipping'
-
-
 class module_audit_disablefunctionbypass:
     error_sh_commands_enabled = 'Error, you can already execute system commands'
     error_mod_cgi_disabled = 'Error, mod_cgi module is not enabled'
@@ -263,11 +251,3 @@ class module_audit_disablefunctionbypass:
     run_s_skip_reinstalling = 'Run console without reinstalling with \':audit_disablefunctionbypass -just-run %s\''
     requests_not_obfuscated = 'Type \'quit\' to return to weevely shell. Requests are not obfuscated'
     cgi_installed_remove_s_s = 'After usage, use \':file_rm\' to remove \'%s\' and \'%s\''
-    
-class module_backdoor_metasploit:
-    msfvenom_s_not_found = "Msfvenom '%s' not found, specify with -msfvenom-path"
-    error_payload_s_requires_lhost = 'Error reverse payload \'%s\' requires LHOST, specify with -lhost'
-    make_sure_run_msfconsole = 'Make sure the listener is running on another terminal as below'
-    error_generating_payload = "Error generating meterpreter payload"
-    error_payload_s_requires_shell_use_php = 'Error payload \'%s\' requires remote shell, use PHP payloads instead'
-    error_searching_writable_folder_under_s = "Error searching writable folder under '%s'"
\ No newline at end of file
