@@ -46,7 +46,7 @@ class Zip(Module):
         )
 
         if result_err:
-            log.warn(result_err)
+            log.warning(result_err)
             return
 
         return True
