@@ -4,7 +4,7 @@ from core import config
 import random
 import string
 import utils
-import urllib2
+import urllib.request, urllib.error, urllib.parse
 import os
 
 agents_list_path = 'utils/_http/user-agents.txt'
@@ -12,16 +12,18 @@ agents_list_path = 'utils/_http/user-agents.txt'
 def load_all_agents():
 
     try:
-        agents_file = open(
+
+        with open(
             os.path.join(config.weevely_path,
             agents_list_path)
-        )
+            ) as agents_file:
+            return agents_file.read().split('\n')
+
     except Exception as e:
         raise FatalException(
             messages.generic.error_loading_file_s_s %
             (agents_list_path, str(e)))
 
-    return agents_file.read().split('\n')
 
 def add_random_url_param(url):
 
@@ -49,6 +51,6 @@ def request(url, headers = []):
     if not next((x for x in headers if x[0] == 'User-Agent'), False):
         headers = [ ('User-Agent', random.choice(load_all_agents())) ]
 
-    opener = urllib2.build_opener()
+    opener = urllib.request.build_opener()
     opener.addheaders = headers
-    return opener.open(url).read()
\ No newline at end of file
+    return opener.open(url).read()
